==> mysql-shell_8.0.36+dfsg.orig.tar.xz: mysql-shell-8.0.36-src/unittest/scripts/auto/js_shell/scripts/cmd_help_commands_norecord.js <==
//@ Multiline Command
\? \

//@ Connect Command
\? \connect

//@ Connect Command, \c [USE:Connect Command]
\? \connect

//@ Edit Command
// WL12763-TSFR2_2 - Validate that the help system has an entry for the `\edit` command.
\? \edit

//@ Edit Command, \e [USE: Edit Command]
\? \e

//@ Exit Command
\? \exit

//@ Help Command
\? \help

//@ Help Command, \h [USE:Help Command]
\? \help

//@ History Command
\? \history

//@ JavaScript Command
\? \js

//@ nopager Command
\? \nopager

//@ Nowarnings Command
\? \nowarnings

//@ Nowarnings Command, \w [USE:Nowarnings Command]
\? \nowarnings

//@ Option Command
\? \option

//@ pager Command
\? \pager

//@ pager Command, \P [USE:pager Command]
\? \P

//@ Python Command
\? \py

//@ Quit Command
\? \q

//@ Reconnect Command
\? \reconnect

//@ Rehash Command
\? \rehash

//@ Show Command
// WL11263_TSF1_1 - Validate that the \help command display information about the new \show command.
// WL11263_TSF2_1 - Validate that the help for \show command specifies that the command take the name report as argument and additional options.
\? \show

//@ Source Command
\? \source

//@ Source Command, \. [USE:Source Command]
\? \.

//@ SQL Command
\? \sql

//@ Status Command
\? \status

//@ Status Command, \s [USE:Status Command]
\? \s

//@ System Command
// WL12763-TSFR1_2 - Validate that the help system has an entry for the `\system` command.
\? \system

//@ System Command, \! [USE: System Command]
\? \!

//@ Use Command
\? \use

//@ Use Command, \s [USE:Use Command]
\? \u

//@ Warnings Command
\? \warnings

//@ Warnings Command, \W [USE:Warnings Command]
\? \W

//@ Watch Command
// WL11263_TSF3_1 - Validate that the \help command display information about the new \watch command.
\? \watch

==> mysql-shell_8.4.6+dfsg.orig.tar.xz: mysql-shell-8.4.6-src/unittest/scripts/auto/js_shell/scripts/cmd_help_commands_norecord.js <==
//@ Multiline Command
\? \

//@ Connect Command
\? \connect

//@ Connect Command, \c [USE:Connect Command]
\? \connect

//@ Edit Command
// WL12763-TSFR2_2 - Validate that the help system has an entry for the `\edit` command.
\? \edit

//@ Edit Command, \e [USE: Edit Command]
\? \e

//@ Exit Command
\? \exit

//@ Help Command
\? \help

//@ Help Command, \h [USE:Help Command]
\? \help

//@ History Command
\? \history

//@ JavaScript Command
\? \js

//@ nopager Command
\? \nopager

//@ Nowarnings Command
\? \nowarnings

//@ Nowarnings Command, \w [USE:Nowarnings Command]
\? \nowarnings

//@ Option Command
\? \option

//@ pager Command
\? \pager

//@ pager Command, \P [USE:pager Command]
\? \P

//@ Python Command
\? \py

//@ Quit Command
\? \q

//@ Reconnect Command
\? \reconnect

//@ Rehash Command
\? \rehash

//@ Show Command
// WL11263_TSF1_1 - Validate that the \help command display information about the new \show command.
// WL11263_TSF2_1 - Validate that the help for \show command specifies that the command take the name report as argument and additional options.
\? \show

//@ Source Command
\? \source

//@ Source Command, \. [USE:Source Command]
\? \.

//@ SQL Command
\? \sql

//@ Status Command
\? \status

//@ Status Command, \s [USE:Status Command]
\? \s

//@ System Command
// WL12763-TSFR1_2 - Validate that the help system has an entry for the `\system` command.
\? \system

//@ System Command, \! [USE: System Command]
\? \!

//@ Use Command
\? \use

//@ Use Command, \s [USE:Use Command]
\? \u

//@ Warnings Command
\? \warnings

//@ Warnings Command, \W [USE:Warnings Command]
\? \W

//@ Watch Command
// WL11263_TSF3_1 - Validate that the \help command display information about the new \watch command.
\? \watch


//@ Query Attributes Command (JavaScript)
\? \query_attributes

//@ Query Attributes Command (Python)
\py
\? \query_attributes

//@ Query Attributes Command (SQL)
\sql
\? \query_attributes
